BackpressureStrategy enum
Backpressure strategy for channel data flow control (CH-07)
Values
- buffer → const BackpressureStrategy
-
Buffer events up to a limit, then drop oldest
- drop → const BackpressureStrategy
-
Drop new events when buffer is full
- latest → const BackpressureStrategy
-
Only keep the latest event
- throttle → const BackpressureStrategy
-
Throttle events by time interval
- debounce → const BackpressureStrategy
-
Debounce events by time interval
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BackpressureStrategy> - A constant List of the values in this enum, in order of their declaration.