BatchResourceLoader class

Loads multiple client resources in a single operation.

Supports parallel and sequential load strategies with configurable failure policies per spec Batch Resource Loading.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadBatch({required List<BatchResourceSource> sources, String loadStrategy = 'parallel', String failurePolicy = 'continue'}) Future<BatchResourceResult>
Load a batch of resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited