ClientActionHandler class

Handles client-side action execution

Constructors

ClientActionHandler(PermissionsConfig? permissionsConfig)
Create a client action handler with the given permission config

Properties

hashCode int
The hash code for this object.
no setterinherited
permissionManager PermissionManager
Get the permission manager for external configuration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Map<String, dynamic> action, RenderContext context) Future<ActionResult>
Execute a client action
init() Future<void>
Initialize the handler
isClientAction(String? actionType) bool
Check if an action type is a client action
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited