CustomResourceProviderRegistry class

Registry for custom client:// resource providers.

Allows applications to extend the client:// protocol with custom schemes accessed as client://<scheme>/path (spec Custom Resource Providers).

Properties

hashCode int
The hash code for this object.
no setterinherited
registeredSchemes List<String>
Return all registered scheme names
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

has(String scheme) bool
Whether a provider is registered for scheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(CustomResourceProvider provider) → void
Register a custom provider for a given scheme.
resolve(String scheme, String path) Future<ResourceResult>
Resolve a URI via the registered provider for scheme
toString() String
A string representation of this object.
inherited
unregister(String scheme) → void
Remove a previously registered provider

Operators

operator ==(Object other) bool
The equality operator.
inherited