Debouncer class

Debouncer utility for performance optimization according to MCP UI DSL v1.0 specification

Constructors

Debouncer({required int milliseconds})

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool
Check if there's a pending action
no setter
milliseconds int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancel any pending action
dispose() → void
Dispose of the debouncer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(void action()) → void
Run the action after the specified delay Cancels any previous pending action
runAsync(Future<void> action()) → void
Run the action asynchronously after the specified delay Cancels any previous pending action
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited