FilePermissionConfig class

File permission configuration

Constructors

FilePermissionConfig({List<String>? allowedPaths, List<String>? allowedExtensions, int? maxSize, bool? requireConfirmation})
FilePermissionConfig.fromJson(Map<String, dynamic> json)
factory

Properties

allowedExtensions List<String>?
Allowed file extensions
final
allowedPaths List<String>?
Allowed paths for file access
final
hashCode int
The hash code for this object.
no setterinherited
maxSize int?
Maximum file size in bytes (for write)
final
requireConfirmation bool?
Whether to require user confirmation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited