IdentityState enum

Who the current session acts as (8.9.2).

Inheritance
Available extensions

Values

guest → const IdentityState

Nobody signed in. The session acts as the bearer of the entry, if any.

identified → const IdentityState

A principal the host identified.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IdentityState>
A constant List of the values in this enum, in order of their declaration.