LifecycleManager class

Manages component and runtime lifecycle events

Constructors

LifecycleManager({bool enableDebugMode = kDebugMode})

Properties

enableDebugMode bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(LifecycleEvent event, Function listener) → void
Registers a listener for a specific lifecycle event
createComponentHandler(String componentId) ComponentLifecycleHandler
Creates a component lifecycle handler
dispose() → void
Disposes of the lifecycle manager and cleans up resources
executeLifecycleHooks(LifecycleEvent event, List hooks) Future<void>
Executes lifecycle hooks defined in the runtime configuration
executeOnDispose(List hooks) Future<void>
Convenience method: execute onDispose lifecycle hooks
executeOnEnter(List hooks) Future<void>
Convenience method: execute onEnter lifecycle hooks (page navigation enter)
executeOnInit(List hooks) Future<void>
Convenience method: execute onInit lifecycle hooks (page-level)
executeOnInitialize(List hooks) Future<void>
Convenience method: execute onInitialize lifecycle hooks (app-level)
executeOnLeave(List hooks) Future<void>
Convenience method: execute onLeave lifecycle hooks (page navigation leave)
executeOnMount(List hooks) Future<void>
Convenience method: execute onMount lifecycle hooks
executeOnPagePause(List hooks) Future<void>
Convenience method: execute page-level onPause lifecycle hooks
executeOnPageResume(List hooks) Future<void>
Convenience method: execute page-level onResume lifecycle hooks
executeOnPause(List hooks) Future<void>
Convenience method: execute onPause lifecycle hooks
executeOnReady(List hooks) Future<void>
Convenience method: execute onReady lifecycle hooks
executeOnResume(List hooks) Future<void>
Convenience method: execute onResume lifecycle hooks
executeOnUnmount(List hooks) Future<void>
Convenience method: execute onUnmount lifecycle hooks
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(LifecycleEvent event, Function listener) → void
Removes a listener for a specific lifecycle event
setActionHandler(dynamic actionHandler, dynamic renderContext) → void
Sets the action handler for executing lifecycle hooks
toString() String
A string representation of this object.
inherited
triggerEvent(LifecycleEvent event, [dynamic data]) Future<void>
Triggers a lifecycle event and executes associated hooks

Operators

operator ==(Object other) bool
The equality operator.
inherited