PermissionCheckResult class

Result of a permission check with prompt

Constructors

PermissionCheckResult.allowed({int? timeout})
Create an allowed result
factory
PermissionCheckResult.denied(String reason)
Create a denied result
factory

Properties

allowed bool
Whether the action is allowed
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
Reason for denial (if not allowed)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
Timeout for the action (if applicable)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited