ResourceDeclaration class

Declaration of a single resource with optional dependency info

Constructors

ResourceDeclaration({required String key, required String source, List<String> dependsOn = const [], bool optional = false, List<Map<String, dynamic>>? transform})
const
ResourceDeclaration.fromJson(String key, Map<String, dynamic> json)
factory

Properties

dependsOn List<String>
Keys of resources that must be ready before this one loads
final
hashCode int
The hash code for this object.
no setterinherited
key String
Unique key for this resource (used in bindings as {{resources.
final
optional bool
Whether failure is silently ignored for this resource
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
The client:// URI to load (may contain binding expressions)
final
transform List<Map<String, dynamic>>?
Optional transformation pipeline
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited