RouteInfo class
Route information
Constructors
Properties
-
allParams
→ Map<
String, dynamic> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageUri → dynamic
-
The route's raw
RouteValue(spec v1.4 1.2.1). Typeddynamicbecause a route may be a resource URI string, an inline page, a transition wrapper, a qualified{ $ref, from }reference to another origin, or a binding. Casting this toStringwould throw on every composed route.final -
pathParams
→ Map<
String, String> -
final
-
queryParams
→ Map<
String, String> -
final
- route → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited