Service class abstract

Service interface for common service operations

Implementers

Constructors

Service()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ServiceStatus
Get service status
no setter

Methods

dispose() Future<void>
Dispose of the service
initialize() Future<void>
Initialize the service
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited