ServicesDefinition class

Services definition

Constructors

ServicesDefinition({Map<String, dynamic>? state, Map<String, dynamic>? navigation, Map<String, dynamic>? dialog, Map<String, dynamic>? notification, Map<String, dynamic>? backgroundServices})
ServicesDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundServices Map<String, dynamic>?
final
dialog Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
final
notification Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited