SplashConfig class

Splash screen configuration.

Constructors

SplashConfig({String? image, String? backgroundColor, int? duration})
const
SplashConfig.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor String?
Background color as hex string (e.g. '#FFFFFF').
final
duration int?
Display duration in milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
image String?
Splash image asset reference or URL.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? image, String? backgroundColor, int? duration}) SplashConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited