Validator class abstract

Base validator class

Implementers

Constructors

Validator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
inherited
validate(dynamic value, RenderContext? context) → ValidationResult
Validate a value

Operators

operator ==(Object other) bool
The equality operator.
inherited