AsyncValidator class abstract
Async validator base class
- Inheritance
- Implementers
Constructors
- AsyncValidator({int debounceMilliseconds = 500})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void - Cancel pending validation
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
dynamic value, RenderContext? context) → ValidationResult -
Validate a value
override
-
validateAsync(
dynamic value, RenderContext? context) → Future< ValidationResult> - Async validation method to implement
-
validateWithDebounce(
dynamic value, RenderContext? context, void callback(ValidationResult)) → void - Validate with debouncing
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited