BatchResourceSource class
A single source entry in a batch resource declaration
Constructors
-
BatchResourceSource({required String key, required String source, bool optional = false, List<
Map< ? transform})String, dynamic> > -
const
-
BatchResourceSource.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Key used to access this resource in results
final
- optional → bool
-
Whether failure of this source should be silently ignored
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
The client:// URI to load
final
-
transform
→ List<
Map< ?String, dynamic> > -
Optional transformation pipeline to apply after loading
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited