ClientPermissions class
Permission types for client actions Uses dot-namespaced format per spec standard
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getRequiredPermission(
String actionType) → String? - Map action types to required permissions
Constants
- clipboard → const String
- Permission to access clipboard
- fileRead → const String
- Permission to read files
- fileWrite → const String
- Permission to write files
- http → const String
- Permission to make HTTP requests
- notification → const String
- Permission to show notifications
- shell → const String
- Permission to execute shell commands
- systemInfo → const String
- Permission to access system info
- websocket → const String
- Permission to use WebSocket connections