CompositeAsyncValidator class
Composite async validator that combines multiple validators
- Inheritance
-
- Object
- Validator
- AsyncValidator
- CompositeAsyncValidator
Constructors
-
CompositeAsyncValidator({required List<
AsyncValidator> validators, bool stopOnFirstError = true, int debounceMilliseconds = 500})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopOnFirstError → bool
-
final
-
validators
→ List<
AsyncValidator> -
final
Methods
-
cancel(
) → void -
Cancel pending validation
inherited
-
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
dynamic value, RenderContext? context) → ValidationResult -
Validate a value
inherited
-
validateAsync(
dynamic value, RenderContext? context) → Future< ValidationResult> -
Async validation method to implement
override
-
validateWithDebounce(
dynamic value, RenderContext? context, void callback(ValidationResult)) → void -
Validate with debouncing
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited