CustomResourceProvider class
A registered custom resource provider
Constructors
-
CustomResourceProvider({required String scheme, required CustomResourceHandler handler, List<
String> permissions = const [], Map<String, dynamic> ? config}) -
const
Properties
-
config
→ Map<
String, dynamic> ? -
Static configuration for the provider
final
- handler → CustomResourceHandler
-
The handler function
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
→ List<
String> -
Required permissions for this provider
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → String
-
The scheme name (e.g., "database", "api")
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited