FlowControlConfig class
Flow control configuration combining inbound and outbound rate limits
Constructors
- FlowControlConfig({RateLimitConfig? inbound, RateLimitConfig? outbound})
-
const
-
FlowControlConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inbound → RateLimitConfig?
-
Rate limit for inbound (received) messages
final
- outbound → RateLimitConfig?
-
Rate limit for outbound (sent) messages
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited