LifecycleEvent enum
Enumeration of lifecycle events supported by the runtime
Values
- initialize → const LifecycleEvent
-
App-level initialization (called once on application start)
- pageInit → const LifecycleEvent
-
Page-level initialization (called on each page enter/mount)
- ready → const LifecycleEvent
- pause → const LifecycleEvent
- resume → const LifecycleEvent
- destroy → const LifecycleEvent
- mount → const LifecycleEvent
- unmount → const LifecycleEvent
- enter → const LifecycleEvent
- leave → const LifecycleEvent
- pagePause → const LifecycleEvent
- pageResume → const LifecycleEvent
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LifecycleEvent> - A constant List of the values in this enum, in order of their declaration.