RuntimeService class abstract
Abstract base class for all runtime services
- Implementers
Constructors
- RuntimeService({bool enableDebugMode = kDebugMode})
Properties
- enableDebugMode → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
Gets whether this service has been initialized
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Disposes of the service and cleans up resources
-
initialize(
Map< String, dynamic> config) → Future<void> - Initializes the service with the provided configuration
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> - Override this method to implement service-specific cleanup
-
onInitialize(
Map< String, dynamic> config) → Future<void> - Override this method to implement service-specific initialization
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited