TrustLevelManager class
Manages the current trust level and validates permission requirements
Constructors
Properties
- currentLevel → TrustLevel
-
The current trust level
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRequiredLevel(
String permissionType) → TrustLevel - Get the trust level required for a permission type
-
isPermissionAllowed(
String permissionType) → bool - Check if the current trust level allows a specific permission type
-
meetsLevel(
TrustLevel required) → bool - Check if current level meets required level
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Reset trust level to default (basic)
-
setLevel(
TrustLevel level) → void - Set the trust level
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited