ViewModeResolver class
Resolves the effective FormFactor by walking the priority chain defined in the responsive-rendering plan 4:
- Per-app pin (
AppConfig.viewMode) - Global pin (
AppSettings.defaultViewMode) - DSL
responsivehint (server-stamped) MediaQueryauto
auto at any step skips that step.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited